==> nextcloud-app-deck-1%3A1.15.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/af.js <==
OC.L10N.register(
    "deck",
    {
    "The file was uploaded" : "Die lêer is opgelaai",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die opgelaaide lêer oorskry die upload_max_filesize riglyn in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die opgelaaide lêer oorskry die MAX_FILE_SIZE riglyn wat in die HTML vorm gespesifiseer is",
    "The file was only partially uploaded" : "Die lêer is slegs gedeeltelik op gelaai",
    "No file was uploaded" : "Geen lêer is opgelaai",
    "Missing a temporary folder" : "Ontbrekende tydelike gids",
    "A PHP extension stopped the file upload" : "’n PHP-uitbreiding het die oplaai gestaak",
    "Later" : "Later",
    "copy" : "kopie",
    "To Do" : "Moet doen",
    "Done" : "Gereed",
    "File" : "Lêer",
    "Cancel" : "Kanselleer",
    "File already exists" : "Lêer bestaan reeds",
    "Open" : "Open",
    "Completed" : "Voltooid",
    "Open details" : "Open besonderhede",
    "Details" : "Besonderhede",
    "Tags" : "Etikette",
    "No participants found" : "Geen deelnemers gevind",
    "Can edit" : "Kan redigeer",
    "Can share" : "Kan deel",
    "Owner" : "Eienaar",
    "Delete" : "Skrap",
    "Edit" : "Wysig",
    "Download" : "Laai af",
    "Modified" : "Gewysig",
    "Created" : "Geskep",
    "Comments" : "Kommentare",
    "Save" : "Stoor",
    "Created:" : "Geskep:",
    "Reply" : "Antwoord",
    "Update" : "Werk by",
    "Description" : "Beskrywing",
    "Select Date" : "Kies Datum",
    "seconds ago" : "sekondes gelede",
    "Keyboard shortcuts" : "Sneltoetse",
    "Keyboard shortcut" : "Snelsleutel",
    "Search" : "Soek",
    "Shared with you" : "Met u gedeel",
    "An error occurred" : "'n Fout het voorgekom",
    "No notifications" : "Geen kennisgewings",
    "Advanced options" : "Gevorderde opsies",
    "Export" : "Voer uit",
    "Today" : "Vandag",
    "Tomorrow" : "Môre",
    "Due date" : "Sperdatum",
    "Share" : "Deel",
    "Personal" : "Persoonlik"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-deck-1%3A1.16.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/deck/l10n/af.js <==
OC.L10N.register(
    "deck",
    {
    "The file was uploaded" : "Die lêer is opgelaai",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Die opgelaaide lêer oorskry die upload_max_filesize riglyn in php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Die opgelaaide lêer oorskry die MAX_FILE_SIZE riglyn wat in die HTML vorm gespesifiseer is",
    "The file was only partially uploaded" : "Die lêer is slegs gedeeltelik op gelaai",
    "No file was uploaded" : "Geen lêer is opgelaai",
    "Missing a temporary folder" : "Ontbrekende tydelike gids",
    "A PHP extension stopped the file upload" : "’n PHP-uitbreiding het die oplaai gestaak",
    "Later" : "Later",
    "copy" : "kopie",
    "To Do" : "Moet doen",
    "Done" : "Gereed",
    "File" : "Lêer",
    "Cancel" : "Kanselleer",
    "File already exists" : "Lêer bestaan reeds",
    "Open" : "Open",
    "Completed" : "Voltooid",
    "Open details" : "Open besonderhede",
    "Details" : "Besonderhede",
    "Tags" : "Etikette",
    "No participants found" : "Geen deelnemers gevind",
    "Can edit" : "Kan redigeer",
    "Can share" : "Kan deel",
    "Owner" : "Eienaar",
    "Delete" : "Skrap",
    "Edit" : "Wysig",
    "Download" : "Laai af",
    "Modified" : "Gewysig",
    "Created" : "Geskep",
    "Comments" : "Kommentare",
    "Save" : "Stoor",
    "Created:" : "Geskep:",
    "Reply" : "Antwoord",
    "Update" : "Werk by",
    "Description" : "Beskrywing",
    "Select Date" : "Kies Datum",
    "seconds ago" : "sekondes gelede",
    "Keyboard shortcuts" : "Sneltoetse",
    "Keyboard shortcut" : "Snelsleutel",
    "Search" : "Soek",
    "Shared with you" : "Met u gedeel",
    "An error occurred" : "'n Fout het voorgekom",
    "No notifications" : "Geen kennisgewings",
    "Advanced options" : "Gevorderde opsies",
    "Export" : "Voer uit",
    "Due date" : "Sperdatum",
    "Share" : "Deel",
    "Personal" : "Persoonlik",
    "Today" : "Vandag",
    "Tomorrow" : "Môre"
},
"nplurals=2; plural=(n != 1);");
